@@ -5,7 +5,7 @@ from django import template
 from fiber import __version__ as fiber_version_number
 from fiber.models import Page, ContentItem
 from fiber.utils.urls import get_admin_change_url
-from fiber.app_settings import PERMISSION_CLASS
+from fiber.app_settings import PERMISSION_CLASS, AUTO_CREATE_CONTENT_ITEMS
 from fiber.utils import class_loader
 
 
@@ -121,7 +121,8 @@ def show_content(context, content_item_name):
     try:
         content_item = ContentItem.objects.get(name__exact=content_item_name)
     except ContentItem.DoesNotExist:
-        pass
+        if AUTO_CREATE_CONTENT_ITEMS:
+            content_item = ContentItem.objects.create(name=content_item_name)
 
     context['content_item'] = content_item
 
